@@ -151,7 +151,7 @@ class BiliMajor:
         try:
             major_type = dyn_major.type
             if major_type == "MAJOR_TYPE_DRAW":
-                return await DynMajorDraw(self.style,item=dyn_major.draw.items).run(repost)
+                return await DynMajorDraw(self.style,items=dyn_major.draw.items).run(repost)
             elif major_type == "MAJOR_TYPE_ARCHIVE":
                 return await DynMajorArchive(self.src_path, self.style, dyn_major).run(repost)
             elif major_type == "MAJOR_TYPE_LIVE_RCMD":
